@@ -54,7 +54,6 @@ extern int parseservices(char *);
 extern int parseadmins(char *);
 extern int parsekickreasons(char *);
 extern int parsechaninfo(char *);
-extern int allhostsknown(struct channel *);
 extern int burstjoins(struct channel *);
 extern int isq(char *);
 extern int isservice(char *);
@@ -109,7 +108,6 @@ extern int delchannel(char *);
 extern int delkickreason(char *);
 extern int getondiskmsgcount(struct channel *, char *);
 extern int getondiskjoincount(struct channel *, char *);
-extern int getrandom(int);
 extern int getrandommsg(struct channel *, char *, int, int, char *, int);
 extern int getjoincount(struct channel *, char *);
 extern int delserver(char *, int, int, int, int, int);
@@ -122,6 +120,7 @@ extern int clonechannel(char *, char *);
 extern int isfriend(struct channel *, char *, char *);
 extern int deltachanflags(struct channel *, char *, char);
 extern int isvalidchannel(char *);
+extern unsigned int getrandom(unsigned int);
 extern struct authed *addnewauthed(struct channel *, time_t, struct botuser *, char *);
 extern struct botuser *addbotuser(char *, char *);
 extern struct botuser *addnewadmin(char *, char *);
@@ -199,7 +198,7 @@ extern void syncvoices(struct channel *);
 extern void syncops(struct channel *);
 extern void syncbans(struct channel *);
 extern void syncnickbks(struct channel *);
-extern void syncuserhosts(char *);
+extern void syncuserhosts(void);
 extern void settopic(struct channel *);
 extern void processenv(void);
 extern void processnetjoin(struct channel *);
