@@ -250,10 +250,12 @@ enum OER_TIMED_PRIORITIES {
 /* from glib.h */
 #define ABS(a)         (((a) < 0) ? -(a) : (a))
 
-#define OER_MAINLOOP_TIMEOUT_SECS 2
+#define OER_MAINLOOP_TIMEOUT_SECS 1
 #define OER_MAINLOOP_TIMEOUT_USECS 0
 /* only change this if you are 100% sure what you are doing */
 #define OER_ACTIONS_PER_MAINLOOP 2
+#define OER_KICKS_PER_MAINLOOP 1
+#define OER_KICK_INTERVAL 2
 #define OER_NICKS_PER_USERHOST 5
 /* multiple kicks aren't supported for backwards compatibility */
 #define OER_NICKS_PER_KICK 1
@@ -331,7 +333,7 @@ enum OER_TIMED_PRIORITIES {
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-44, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-45, Copyright (C) 2000-2001 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -359,6 +361,7 @@ struct locked {
 	int locked;
 	int unlocked;
 	int auto_unlock;
+	time_t lastkick;
 	char reason[STRINGLEN + 1];
 	char nick[NICKLEN + 1];
 	char host[USERHOSTLEN + 1];
@@ -505,6 +508,7 @@ struct channel {
 	int topic_list;
 	int synced;
 	int bantype;
+	int allhostsknown;
 	time_t rejoin_at;
 	time_t last_quote;
 	FILE *seen;
