@@ -1041,7 +1041,6 @@ void parsemsg(char *nick, char *userhost, char *target, char *message)
 		updatelast(this, nick, userhost, message);
 	}
 }
-
 void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 {
 	int proceed;
@@ -1054,6 +1053,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
         int prevppos;
 	time_t uptime_seconds;
 	time_t idle_seconds;
+	time_t idle_per;
         char p1[STRINGLEN + 1];
         char p2[STRINGLEN + 1];
 	char outstring[WRITE_BUFFER_LENGTH + 1];
@@ -1348,16 +1348,18 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if(!this->i_am_op) {
 			return;
 		}
-		if(!isadmin(this, userhost)) {
-			if(haschanflags(this, "l")) {
-				if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
-					return;
-				}
-				if(!isatleastopnow(this, nick, userhost)) {
-					return;
-				}
-			}
-		}
+		/* allow admins to lock even if not "l" chanflag */
+                if(!isadmin(this, userhost)) {
+                        if(!haschanflags(this, "l")) {
+                                return;
+                        }
+                        if(haschanflags(this, "U") && !isatleastop(this, nick, userhost)) {
+                                return;
+                        }
+                        if(!isatleastopnow(this, nick, userhost)) {
+                                return;
+                        }
+                }
 		lockchan(this, restptr, (which == OER_WHICHCOMMAND_LOCK) ? 0 : 1, nick, userhost);
 		return;
 	case OER_WHICHCOMMAND_UNLOCK:
@@ -2027,16 +2029,20 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		}
 		secondstostring(mystate->now - mystate->startup, uptimestring, STRINGLEN);
 		snprintf(outstring, WRITE_BUFFER_LENGTH, "oer uptime: %s", uptimestring);
-		if(!uptime(&uptime_seconds, &idle_seconds)) {
-			return;
-		}
-		secondstostring(uptime_seconds, uptimestring, STRINGLEN);
+		if(uptime(&uptime_seconds, &idle_seconds)) {
+			secondstostring(uptime_seconds, uptimestring, STRINGLEN);
+			idle_per = idle_seconds % uptime_seconds;
+			idle_per = uptime_seconds - idle_per;
+			idle_per *= 100;
+			idle_per /= uptime_seconds;
+			idle_per = 100 - idle_per;
 #ifdef OER_UPTIME_SHOW_IDLE
-		snprintf(outstring2, WRITE_BUFFER_LENGTH, ", server uptime: %s (idle %.2f%%)", uptimestring, ((float)((float)idle_seconds/(float)uptime_seconds) * 100.0));
+			snprintf(outstring2, WRITE_BUFFER_LENGTH, ", host uptime: %s (host idle: %lu%%)", uptimestring, idle_per);
 #else
-		snprintf(outstring2, WRITE_BUFFER_LENGTH, ", server uptime: %s", uptimestring);
+			snprintf(outstring2, WRITE_BUFFER_LENGTH, ", host uptime: %s", uptimestring);
 #endif
-		strncat(outstring, outstring2, WRITE_BUFFER_LENGTH - strlen(outstring));
+			strncat(outstring, outstring2, WRITE_BUFFER_LENGTH - strlen(outstring));
+		}
 		sendreply((tochan) ? channel : nick, tochan, 0, 1, outstring);
 		return;
 	case OER_WHICHCOMMAND_ACTION:
